/* 
  Copyright (c) 1989, 1990, 1991 by the University of Washington

  Permission to use, copy, modify, and distribute this software and its
  documentation for non-commercial purposes and without fee is hereby
  granted, provided that the above copyright notice appear in all copies
  and that both the copyright notice and this permission notice appear in
  supporting documentation, and that the name of the University of
  Washington not be used in advertising or publicity pertaining to
  distribution of the software without specific, written prior
  permission.  The University of Washington makes no representations
  about the suitability of this software for any purpose.  It is
  provided "as is" without express or implied warranty.

  Prospero was written by Clifford Neuman (bcn@isi.edu).

  Questions concerning this software should be directed to 
  info-prospero@isi.edu.

  */
