/*
 * Archie v1.2
 *
 * History:
 *
 * 11/20/91 v1.2 - Release.
 * 11/18/91      - ported to DOS & OS/2
 * 11/12/91      - finally got to test under Multinet 3.0
 * 10/03/91      - replaced regex.c for oz
 * 09/25/91	 - added Wallongong support
 * 08/30/91      - ported to VMS
 * 08/20/91 v1.1 - Major revisions
 * 07/31/91 v1.0 - Original
 */
